<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="vi" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Thông tin về</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Khởi chạy torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Bỏ qua kiểm tra hash</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Uncategorized</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resume torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit category...</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Mỗi dòng chỉ chứa một liên kết</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Giới hạn số lượng tối đa các kết nối phải lớn hơn 0 nếu không sẽ bị vô hiệu hóa.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Giới hạn số lượng tối đa các kết nối của mỗi torrent phải lớn hơn 0 nếu không sẽ bị vô hiệu hóa.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Giới hạn số lượng tối đa các phần tải lên của mỗi torrent phải lớn hơn 0 nếu không sẽ bị vô hiệu hóa.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Không thể lưu các tùy biến của chương trình, qBittorrent có thể không thể được điều khiển theo mong muốn.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Login</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Original authors</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save files to location:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Cookie:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Type folder here</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>More information</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Information about certificates</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Set location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Limit download rate</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Rename torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Logout</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save</source>
        <translation>Lưu lại</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Hiện không thể kết nối đến máy trạm của qBittorrent</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Unable to create category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Free space: %1</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Saving Management</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Chỉnh Sửa</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Công Cụ</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Tập Tin</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Trợ Giúp</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Chế Độ Xem</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Tùy Chọn...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Hoạt Động Trở Lại</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Top Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Increase Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Status Bar</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Donate!</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resume All</source>
        <translation>Đưa tất cả hoạt động trở lại</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>About</source>
        <translation>Thông tin</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tạm Dừng</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Tạm Dừng Tất Cả</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Documentation</source>
        <translation>Tài Liệu Hướng Dẫn</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Yes</source>
        <translation>Đồng Ý</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Không Đồng Ý</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Giới Hạn Tốc Độ Tải Lên Chung</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Giới Hạn Tốc Độ Tải Xuống Chung</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search Engine</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Transfers</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Speed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>BitTorrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Web UI</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Language</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>IP Filtering</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>IP address:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Server domains:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>SMTP server:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Listening Port</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connections Limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Proxy Server</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>(None)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>SOCKS4</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>SOCKS5</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>HTTP</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Every day</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Weekdays</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Weekends</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Privacy</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Require encryption</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disable encryption</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>then</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause them</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove them</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Certificate:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Key:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Register</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Domain name:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%L: Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%D: Save path</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/giây</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Change current password</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Security</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Files location:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Flags</source>
        <translation>Cờ Đánh Dấu</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Kết nối</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Máy trạm</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Tiến độ</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Tốc độ tải về</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Tốc độ tải lên</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Đã tải về</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Đã tải lên</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Country</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Bình thường</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Ưu tiên cao</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Ưu tiên tối đa</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Tổng Quan</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Mạng ngang hàng</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Nguồn HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Nội dung</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Đã tải về:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Truyền Đổi</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>ETA:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Đã tải lên:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download Speed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Peers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download Limit:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Đã hao hụt:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Kết nối:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Thông tin</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Bình luận:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Total Size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pieces:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Created By:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Added On:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Completed On:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Created On:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save Path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Never</source>
        <translation>Không bao giờ</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download limit:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload limit:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Override Save Location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Monitored folder</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Default save location</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/giây</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Thống kê</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Thống kê người dùng</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Thống kê bộ nhớ đệm</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connected peers:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time download:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session waste:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All-time upload:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Thống kê hiệu suất</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Tác vụ Nhập/Xuất đang đợi thực thi:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Ghi dữ liệu đè lên bộ nhớ đệm:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Đọc dữ liệu từ bộ nhớ đệm bị tràn:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Tổng kích thước hàng đợi:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 nút</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Completed (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Paused (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Active (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Errored (0)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All (%1)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Active (%1)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Tên</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Kích thước</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Tiến độ</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remaining</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Availability</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Tên</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Kích thước</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Đã hoàn tất</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Trạng thái</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Seed</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Mạng ngang hàng</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Tốc độ tải về</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Tốc độ tải lên</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Tỉ lệ</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>ETA</translation>
    </message>
    <message>
        <source>Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tags</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Được thêm vào</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Hoàn tất vào</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Giới hạn tải</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Giới hạn tải lên</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Đã tải về</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Đã tải lên</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Còn lại</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Thời gian thực thi:</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Lưu đường dẫn</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>Đường dẫn</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Trạng thái</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Mạng ngang hàng</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Thông báo</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Updating...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>#</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeds</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Not working</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Tracker editing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leeches</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Remove tracker</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Hộp thoại bổ sung của tracker</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Danh sách các tracker để thêm vào (từng dòng một):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Allocating</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Moving</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Errored</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Missing Files</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Queued for checking</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Checking resume data</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stalled</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Categories</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Đang giới hạn tốc độ tải về của torrent</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Đang giới hạn tốc độ tải lên của torrent</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Đổi tên</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Khôi phục lại</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Tạm dừng</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Xóa</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Giới hạn tỉ lệ chia sẻ...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Giới hạn tỉ lệ tải lên...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Giới hạn tỉ lệ tải về...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Di chuyển lên trên</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Di chuyển xuống dưới</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Di chuyển lên trên cùng</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Di chuyển xuống dưới cùng</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Đặt vị trí...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy hash</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Priority</source>
        <translation>Độ ưu tiên</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Buộc kiểm tra lại</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Sao chép đường dẫn magnet</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Chế độ seed cao cấp</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Đổi tên...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Tải về theo thứ tự tuần tự</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>New name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Set location</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Force reannounce</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit Category</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save path</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Tỉ lệ giới hạn tải lên/tải về torrent</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Set no share limit</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Set share limit to</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>ratio</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Home Page:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Forum:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Đồng thời xóa các tập tin trên ổ đĩa</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download</source>
        <translation>Tải về</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation type="unfinished" />
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/giây</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1 giờ %2 phút</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1d %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Chưa rõ</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1phút</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1phút</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Plugin path:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>URL or local directory</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Install plugin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All plugins</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search plugins...</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>All categories</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search in:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Go to description page</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Results (showing</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Torrent names only</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Only enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>out of</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Everywhere</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Install new plugin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Check for updates</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search plugins</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Leechers</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Search engine</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeders</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished" />
    </message>
</context>
</TS>